@@ -5,17 +5,20 @@ use Catalyst;
 use FindBin;
 
 TestApp->config(
-    root => "$FindBin::Bin/root",
-    default_view => 'TT',
+    root            => "$FindBin::Bin/root",
+    default_view    => 'TT',
     'View::Email::AppConfig' => {
         sender => {
-            method => 'Test',
+            mailer => 'Test',
         },
     },
     'View::Email::Template::AppConfig' => {
         stash_key => 'template_email',
         sender => {
-            method => 'Test',
+            mailer => 'Test',
+        },
+        default => {
+            view => 'TT',
         },
     },
 );
